#!/usr/bin/env python
# -*- coding: utf-8 -*-

# # example of a corrplot
# 
# [Biokit](https://github.com/biokit/biokit) proposes nice graphs for correlation: [corrplot function in Python](http://thomas-cokelaer.info/blog/2014/10/corrplot-function-in-python/) but it only works with Python 2.7. I took the code out and put a modified version of in [pyensae](http://www.xavierdupre.fr/app/pyensae/helpsphinx/).

# In[1]:


get_ipython().run_line_magic('matplotlib', 'inline')


# In[2]:


import pyensae
import matplotlib.pyplot as plt
plt.style.use('ggplot')


# In[3]:


import pandas
import numpy
letters = "ABCDEFGHIJKLM"[0:10]
df = pandas.DataFrame(dict(( (k, numpy.random.random(10)+ord(k)-65) for k in letters)))
df.head()


# In[4]:


from pyensae.graphhelper import Corrplot


# In[5]:


c = Corrplot(df)
c.plot(figsize=(12,6))


# To avoid created another graph container:

# In[6]:


fig = plt.figure(num=None, facecolor='white', figsize=(12,6))
ax = plt.subplot(1, 1, 1, aspect='equal', facecolor='white')
c = Corrplot(df)
c.plot(ax=ax)


# We compare it with [seaborn](http://stanford.edu/~mwaskom/software/seaborn/) and this example
# [Discovering structure in heatmap data](http://stanford.edu/~mwaskom/software/seaborn/examples/structured_heatmap.html).

# In[7]:


import seaborn as sns


# In[8]:


cmap = sns.diverging_palette(h_neg=210, h_pos=350, s=90, l=30, as_cmap=True, center="light")
sns.clustermap(df.corr(), figsize=(10, 10), cmap=cmap)


# In[9]: